#delimit ;
set more 1;

*CREATING AN UNDOCUMENTED IDENTIFIER;

* CORRECT FOR H1B DURING IMPUTATION PROCEDURE, SO SPOUSES AFFECTED;

capture log close;
log using "Logs/create_acs.log",replace;

use ACS/acs.dta, clear;

keep if year>=2008;

* DROP PREVIOUS CODES, SINCE I RE-SAVE USING SAME DATA FILE;
capture drop immigrant;
capture drop imm;
capture drop gbtype*;
capture drop h1b*;
capture drop edcode;
capture drop ysm;
capture drop fine*;
capture drop good;
capture drop slegal*;
capture drop hlegal*;
capture drop code*;
gen imm=(citizen==2 | citizen==3);

generate gbtype=.;

*DEFINE THE NATIVE BORN;
replace gbtype=3 if imm==0;

*A PERSON IS LEGAL IF ARRIVED BEFORE 1980;
replace gbtype=2 if imm==1 & yrimmig<1980;

*A PERSON IS LEGAL IF A CITIZEN;
replace gbtype=2 if imm==1 & citizen==2;

*PERSON IS LEGAL IF RECEIVES SOCIAL SECURITY, SSI, MEDICAID, MEDICARE, OR MILITARY INSURANCE;
replace gbtype=2 if imm==1 & incss>0 & incss<99999;
replace gbtype=2 if imm==1 & incsupp>0 & incsupp<99999;
replace gbtype=2 if imm==1 & hinscaid==2;
replace gbtype=2 if imm==1 & hinscare==2;
replace gbtype=2 if imm==1 & hinsva==2;

*PERSON IS LEGAL IF WORKS FOR ARMED FORCES, GOVERNMENT, OR IS VETERAN;
replace gbtype=2 if imm==1 & classwkrd>=25 & classwkrd<=28;
replace gbtype=2 if imm==1 & vetstat==2;

/*
*HOUSEHOLDER LIVING IN PUBLIC HOUSING OR RECEIVING SUBSIDIZED RENTS IS LEGAL;
*PUBLIC HOUSING INFORMATION NOT AVAILABLE IN POST=2008 ACS;
replace gbtype=2 if imm==1 & relate==101 & pubhous==2;
replace gbtype=2 if imm==1 & relate==101 & rentsub==2;

*SPOUSES AND CHILDREN OF HOUSEHOLDER LIVING IN PUBLIC HOUSING OR RECEIVING SUBSIDIZED RENTS ARE LEGAL;
replace gbtype=2 if imm==1 & pubhous==2 & (relate==201 | relate==301 | relate==901);
replace gbtype=2 if imm==1 & rentsub==2 & (relate==201 | relate==301 | relate==901);
*/

*CUBANS ARE LEGAL;
replace gbtype=2 if imm==1 & bpld==25000;

*WORKERS IN LICENSED OCCUPATIONS ARE LEGAL;
* FROM LABOUR ECON PAPER;
replace gbtype=2 if imm==1 &
	((occ1990==3 | occ1990==4 )
	| (occ1990==16 | occ1990==19)
	| (occ1990==23 | occ1990==35 | occ1990==36 | occ1990==43)
	| (occ1990>=84 & occ1990<=89) | (occ1990>=95 & occ1990<=97)
	| (occ1990>=155 & occ1990<=163)
	| (occ1990>=178 & occ1990<=179) 
	| (occ1990>=203 & occ1990<=208) 
 	| (occ1990==226 | occ1990==227)
	| occ1990==375
	| (occ1990>=417 & occ1990<=423) | occ1990==489
	| occ1990==905);
	

* H1B CORRECTION:;
generate ysm=year-yrimmig;
replace ysm = 0 if imm==0;
generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64)
	+ 3*(educd>=65 & educd<=90) + 4*(educd==100 | educd==101) + 5*(educd>=110);
generate h1b_ctr=(bpl==521 | bpl==500 | bpl==150 | bpl==502 | bpl==515);
generate h1b_occ=(occ==110) | (occ>=1000 & occ<=1240) | occ==2200 | (occ>=1300 & occ<=1560);
generate h1b=(h1b_occ==1 & ysm<=6 & edcode>=4);
* GENERATE ALTERNATE H1B FILTER WHICH USES COUNTRY BUT NOT YSM;
generate h1b_alt=(h1b_occ==1 & h1b_ctr==1 & edcode>=4);
generate h1b_alt2=(h1b_occ==1 & edcode>=4);
* PRESERVE THE NO H1B CORRECTION FOR COMPARISON:;
g gbtype_noh1b = gbtype;
g gbtype_h1balt = gbtype;
g gbtype_h1balt2 = gbtype;
replace gbtype=2 if imm==1 & h1b==1;
replace gbtype_h1balt=2 if imm==1 & h1b_alt==1;
replace gbtype_h1balt2=2 if imm==1 & h1b_alt2==1;


drop ysm edcode;
	

*CREATES VARIABLE FINE, INDICATING PERSON IS EITHER LEGAL OR NATIVE-BORN;
generate fine=(imm==0 | gbtype==2);
generate fine_noh1b=(imm==0 | gbtype_noh1b==2);
generate fine_h1balt=(imm==0 | gbtype_h1balt==2);
generate fine_h1balt2=(imm==0 | gbtype_h1balt2==2);


*HEADHOLDER SPOUSE OF LEGAL "SPOUSE" IS LEGAL;
generate good=.;
replace good=1 if relate==2 & imm==1;
egen slegal=mean(good*fine), by(year serial);
egen slegal_noh1b=mean(good*fine_noh1b), by(year serial);
egen slegal_h1balt=mean(good*fine_h1balt), by(year serial);
egen slegal_h1balt2=mean(good*fine_h1balt2), by(year serial);
tabulate slegal;
replace gbtype=2 if slegal>0 & imm==1 & (relate==1 & marst==1);
replace gbtype_noh1b=2 if slegal_noh1b>0 & imm==1 & (relate==1 & marst==1);
replace gbtype_h1balt=2 if slegal_h1balt>0 & imm==1 & (relate==1 & marst==1);
replace gbtype_h1balt2=2 if slegal_h1balt2>0 & imm==1 & (relate==1 & marst==1);
drop slegal slegal_noh1b;

*SPOUSES, CHILDREN, GRANDCHILDREN OF LEGAL HOUSEHOLDERS ARE LEGAL;
drop good;
generate good=.;
replace good=1 if relate==1 & imm==1;
egen hlegal=mean(good*fine), by(year serial);
egen hlegal_noh1b=mean(good*fine_noh1b), by(year serial);
egen hlegal_h1balt=mean(good*fine_h1balt), by(year serial);
egen hlegal_h1balt2=mean(good*fine_h1balt2), by(year serial);
tabulate hlegal;
replace gbtype=2 if hlegal>0 & imm==1 & ((relate==2 & marst==1) | relate==3 | relate==9);
replace gbtype_noh1b=2 if hlegal_noh1b>0 & imm==1 & ((relate==2 & marst==1) | relate==3 | relate==9);
replace gbtype_h1balt=2 if hlegal_h1balt>0 & imm==1 & ((relate==2 & marst==1) | relate==3 | relate==9);
replace gbtype_h1balt2=2 if hlegal_h1balt2>0 & imm==1 & ((relate==2 & marst==1) | relate==3 | relate==9);

*THE RESIDUAL IMMIGRANTS ARE UNDOCUMENTED;
replace gbtype=1 if gbtype==.;
replace gbtype_noh1b=1 if gbtype_noh1b==.;
replace gbtype_h1balt=1 if gbtype_h1balt==.;
replace gbtype_h1balt2=1 if gbtype_h1balt2==.;


*CODE =1 FOR NATIVES, 2 FOR LEGAL IMMIGRANTS, 3 FOR UNDOCUMENTED IMMIGRANTS;
generate code=1 if gbtype==3;
replace code=2 if gbtype==2;
replace code=3 if gbtype==1;
generate code_noh1b=1 if gbtype_noh1b==3;
replace code_noh1b=2 if gbtype_noh1b==2;
replace code_noh1b=3 if gbtype_noh1b==1;
generate code_h1balt=1 if gbtype_h1balt==3;
replace code_h1balt=2 if gbtype_h1balt==2;
replace code_h1balt=3 if gbtype_h1balt==1;
generate code_h1balt2=1 if gbtype_h1balt2==3;
replace code_h1balt2=2 if gbtype_h1balt2==2;
replace code_h1balt2=3 if gbtype_h1balt2==1;

drop gbtype* good fine;
tabulate year code [fw=perwt];

preserve;
keep year serial pernum code*;
sort year serial pernum;

save ACS/gbtype_acs.dta, replace;
restore;

save ACS/acs.dta, replace;

