keep if year>=2010
keep if age>=21 & age<=64
keep if occ!=.
keep if occ1990!=.
drop if occ==0 | occ==9920

* RECODE SALES REP (OTHER) WHICH IS MISSING IN ONET
replace occsoc = "412031" if occsoc=="413099"

* NOW GENERATE SUBSTRING OCCSOC CODES THAT REMOVE X'S AT DIFFERENT LEVELS
g occsoc1 = substr(occsoc,1,5)
g occsoc2 = substr(occsoc,1,4)
g occsoc3 = substr(occsoc,1,3)
g occsoc4 = substr(occsoc,1,2)

* DESTRING VARIABLES TO ALLOW MERGING
* THIS REQUIRES REPLACE X'S WITH 0'S
replace occsoc = subinstr(occsoc,"X","0",.)
replace occsoc = subinstr(occsoc,"Y","0",.)
destring occsoc,replace
replace occsoc1 = subinstr(occsoc1,"X","0",.)
replace occsoc1 = subinstr(occsoc1,"Y","0",.)
destring occsoc1,replace
replace occsoc2 = subinstr(occsoc2,"X","0",.)
replace occsoc2 = subinstr(occsoc2,"Y","0",.)
destring occsoc2,replace
replace occsoc3 = subinstr(occsoc3,"X","0",.)
replace occsoc3 = subinstr(occsoc3,"Y","0",.)
destring occsoc3,replace
replace occsoc4 = subinstr(occsoc4,"X","0",.)
replace occsoc4 = subinstr(occsoc4,"Y","0",.)
destring occsoc4,replace


* MERGE WITH O*NET TASKS REPEATEDLY AT DIFFERENT LEVELS
* GO IN REVERSE SO THAT A MORE PRECISE MATCH IS PREFERENCED

merge m:1 occsoc using "ONET\soc_tasks4",nogen update
merge m:1 occsoc using "ONET\soc_tasks3",nogen update
merge m:1 occsoc using "ONET\soc_tasks2",nogen update
merge m:1 occsoc using "ONET\soc_tasks1",nogen update
merge m:1 occsoc using "ONET\soc_tasks0",nogen update

drop if year==.


* TAKE MEAN ACROSS ALL WORKERS WITHIN AN occ1990 OCCUPATION CODE
* MULTIPLE SOC CODES MAY MAP INTO A SINGLE OCC CODE


unab varlist : datavalue*

foreach x in `varlist' {
	quietly by occ1990,sort: egen `x'temp = wtmean(`x'),weight(perwt)
	quietly replace `x' = `x'temp	
	quietly drop `x'temp	
}

* GENERATE IMAI, STACEY, AND WARMAN TASK USAGES FOR ANALYTICAL, INTERACTIVE, AND MANUAL TASK USAGE
g ana = 0
g inter = 0
g man = 0

local ana "datavalue1A1b4 datavalue1A1b5 datavalue1A1b6 datavalue1A1b7 datavalue1A1c1 datavalue1A1c2 datavalue1C7b datavalue4A2b1 datavalue2C4a"
pca `ana' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `ana' {
	replace ana = ana + `q'*Z[`k',1]
	local k = `k' + 1
}


local inter "datavalue1A1a1 datavalue1A1a2 datavalue1A1a3 datavalue1A1a4 datavalue1A4b4 datavalue1A4b5 datavalue4A4a1 datavalue4A4a2 datavalue4A4a3 datavalue4A4a4"
pca `inter' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `inter' {
	replace inter = inter + `q'*Z[`k',1]
	local k = `k' + 1
}

local man "datavalue1A3a1 datavalue1A3a3 datavalue1A3a4 datavalue1A3b1 datavalue4A3a1 datavalue4A3a2"
pca `man' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `man' {
	replace man = man + `q'*Z[`k',1]
	local k = `k' + 1
}


* OTHER TASK TYPES, 5 TOTAL:
g nonrana = 0
g nonrinter = 0
g rcog = 0
g rman = 0
g nonrman = 0


local nonrana "datavalue4A2b4 datavalue4A2b2 datavalue4A2b1 datavalue4A2a3 datavalue2B4e datavalue2B2i datavalue2A2b datavalue2A2a datavalue1C7b datavalue1C7a datavalue1A1b2 datavalue1A1b1"
pca `nonrana' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `nonrana' {
	replace nonrana = nonrana + `q'*Z[`k',1]
	local k = `k' + 1
}

local nonrinter "datavalue4A4c2 datavalue4A4b1 datavalue4A4a4 datavalue4A4a1 datavalue2B5d datavalue2B1c datavalue2A2d datavalue1C2b"
pca `nonrinter' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `nonrinter' {
	replace nonrinter = nonrinter + `q'*Z[`k',1]
	local k = `k' + 1
}

local rcog "datavalue2A1e datavalue1A1d1 datavalue1A1c2 datavalue1A1b6"
pca `rcog' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `rcog' {
	replace rcog = rcog + `q'*Z[`k',1]
	local k = `k' + 1
}

local rman "datavalue1A2c2 datavalue1A2a3 datavalue1A2a2"
pca `rman' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `rman' {
	replace rman = rman + `q'*Z[`k',1]
	local k = `k' + 1
}

local nonrman "datavalue4A3a4 datavalue1A2b1 datavalue2B3l datavalue4A3a3 datavalue4A3a1 datavalue1A2b4 datavalue1A2b2"
pca `nonrman' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `nonrman' {
	replace nonrman = nonrman + `q'*Z[`k',1]
	local k = `k' + 1
}


* NEW TASKS:
g cog = 0
g noncog = 0

local cog "datavalue1A1b4 datavalue1A1b5 datavalue1A1b6 datavalue1A1b7 datavalue1A1c1 datavalue1A1c2 datavalue1C7b datavalue4A2b1 datavalue2C4a datavalue1A1a1 datavalue1A1a2 datavalue1A1a3 datavalue1A1a4 datavalue1A4b4 datavalue1A4b5 datavalue4A4a1 datavalue4A4a2 datavalue4A4a3 datavalue4A4a4"

pca `cog' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `cog' {
	replace cog = cog + `q'*Z[`k',1]
	local k = `k' + 1
}

local noncog "datavalue1A3a1 datavalue1A3a3 datavalue1A3a4 datavalue1A3b1 datavalue4A3a1 datavalue4A3a2 datavalue1A2a1 datavalue1A2a2 datavalue1A2b1 datavalue1A2b2 datavalue1A2b3 datavalue1A2b4 datavalue1A2c1 datavalue1A2c3"

pca `noncog' [aw=perwt], comp(1) 
matrix Z = e(L)
local k=1
foreach q in `noncog' {
	replace noncog = noncog + `q'*Z[`k',1]
	local k = `k' + 1
}


* STANDARDIZE TASK SCORES, MEAN ZERO, S.D. ONE
* NEW TASKS:
qui sum cog [aw=perwt]
replace cog = (cog-r(mean))/r(sd)
qui sum noncog [aw=perwt]
replace noncog = (noncog-r(mean))/r(sd)



qui sum ana [aw=perwt]
replace ana = (ana-r(mean))/r(sd)
qui sum inter [aw=perwt]
replace inter = (inter-r(mean))/r(sd)
qui sum man [aw=perwt]
replace man = (man-r(mean))/r(sd)

qui sum nonrana [aw=perwt]
replace nonrana = (nonrana-r(mean))/r(sd)
qui sum nonrinter [aw=perwt]
replace nonrinter = (nonrinter-r(mean))/r(sd)
qui sum rcog [aw=perwt]
replace rcog = (rcog-r(mean))/r(sd)
qui sum rman [aw=perwt]
replace rman = (rman-r(mean))/r(sd)
qui sum nonrman [aw=perwt]
replace nonrman = (nonrman-r(mean))/r(sd)





* NOW, KEEP ONLY ONE CENSUS OCCUPATION:
by occ1990,sort: g tempval1990 = _n
keep if tempval1990 == 1



keep occ1990 sex ana inter man nonrana nonrinter rcog rman nonrman cog noncog

